api.datastores.v1.test_helpers.descriptor package — Argus-Toolbelt 1.0 documentation

# api.datastores.v1.test_helpers.descriptor package

## Submodules

## api.datastores.v1.test_helpers.descriptor.add_data_store_descriptor module

`api.datastores.v1.test_helpers.descriptor.add_data_store_descriptor.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor, respond with HTTP 403

`api.datastores.v1.test_helpers.descriptor.add_data_store_descriptor.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor, respond with HTTP 404

`api.datastores.v1.test_helpers.descriptor.add_data_store_descriptor.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor, respond with HTTP 200

`api.datastores.v1.test_helpers.descriptor.add_data_store_descriptor.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor, respond with HTTP 401

## api.datastores.v1.test_helpers.descriptor.delete_data_store_descriptor module

`api.datastores.v1.test_helpers.descriptor.delete_data_store_descriptor.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 403

`api.datastores.v1.test_helpers.descriptor.delete_data_store_descriptor.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 404

`api.datastores.v1.test_helpers.descriptor.delete_data_store_descriptor.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 200

`api.datastores.v1.test_helpers.descriptor.delete_data_store_descriptor.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 401

## api.datastores.v1.test_helpers.descriptor.get_descriptor module

`api.datastores.v1.test_helpers.descriptor.get_descriptor.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 403

`api.datastores.v1.test_helpers.descriptor.get_descriptor.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 404

`api.datastores.v1.test_helpers.descriptor.get_descriptor.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 200

`api.datastores.v1.test_helpers.descriptor.get_descriptor.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 401

## api.datastores.v1.test_helpers.descriptor.search_descriptors module

`api.datastores.v1.test_helpers.descriptor.search_descriptors.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/search, respond with HTTP 403

`api.datastores.v1.test_helpers.descriptor.search_descriptors.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/search, respond with HTTP 404

`api.datastores.v1.test_helpers.descriptor.search_descriptors.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/search, respond with HTTP 200

`api.datastores.v1.test_helpers.descriptor.search_descriptors.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/search, respond with HTTP 401

## api.datastores.v1.test_helpers.descriptor.search_descriptors_simple module

`api.datastores.v1.test_helpers.descriptor.search_descriptors_simple.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor, respond with HTTP 403

`api.datastores.v1.test_helpers.descriptor.search_descriptors_simple.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor, respond with HTTP 404

`api.datastores.v1.test_helpers.descriptor.search_descriptors_simple.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor, respond with HTTP 200

`api.datastores.v1.test_helpers.descriptor.search_descriptors_simple.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor, respond with HTTP 401

## api.datastores.v1.test_helpers.descriptor.update_data_store_descriptor module

`api.datastores.v1.test_helpers.descriptor.update_data_store_descriptor.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 403

`api.datastores.v1.test_helpers.descriptor.update_data_store_descriptor.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 404

`api.datastores.v1.test_helpers.descriptor.update_data_store_descriptor.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 200

`api.datastores.v1.test_helpers.descriptor.update_data_store_descriptor.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/descriptor/w+, respond with HTTP 401

## Module contents